@@ -30,8 +30,11 @@ const PD_FLOATSIZE: &str = "64";
 fn main() {
     // Directories
     let project_dir = std::path::PathBuf::from(env!("CARGO_MANIFEST_DIR"));
+
     let libpd_dir = project_dir.join("libpd");
+    let pd_source = libpd_dir.join("pure-data").join("src");
     let libpd_wrapper_dir = libpd_dir.join("libpd_wrapper");
+    let libpd_wrapper_util_dir = libpd_wrapper_dir.join("util");
 
     // Transform values of the #include fields in libpd sources to include right paths.
     // Somehow the build script complains if they don't include relative paths but just header names.
@@ -123,6 +126,9 @@ fn main() {
             .define("PD_MULTI", pd_multi)
             .define("PD_UTILS", PD_UTILS)
             .cflag(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
+            .cflag(format!("-I{}", pd_source.to_str().unwrap()))
+            .cflag(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
+            .cflag(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
             .define("CMAKE_THREAD_LIBS_INIT", pthread_lib_path.to_str().unwrap())
             .define("PTHREADS_INCLUDE_DIR", pthread_include.to_str().unwrap())
             .no_build_target(true)
@@ -160,6 +166,9 @@ fn main() {
             .define("PD_MULTI", pd_multi)
             .define("PD_UTILS", PD_UTILS)
             .cflag(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
+            .cflag(format!("-I{}", pd_source.to_str().unwrap()))
+            .cflag(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
+            .cflag(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
             .no_build_target(true)
             .always_configure(true)
             .very_verbose(true)
@@ -182,7 +191,9 @@ fn main() {
             .define("PD_LOCALE", PD_LOCALE)
             .define("PD_MULTI", pd_multi)
             .define("PD_UTILS", PD_UTILS)
-            .cflag(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
+            .cflag(format!("-I{}", pd_source.to_str().unwrap()))
+            .cflag(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
+            .cflag(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
             .define("CMAKE_OSX_ARCHITECTURES", "x86_64;arm64")
             .no_build_target(true)
             .always_configure(true)
@@ -222,6 +233,9 @@ fn main() {
     let bindings = bindgen::Builder::default()
         .header("wrapper.h")
         .rustfmt_bindings(true)
+        .clang_arg(format!("-I{}", pd_source.to_str().unwrap()))
+        .clang_arg(format!("-I{}", libpd_wrapper_dir.to_str().unwrap()))
+        .clang_arg(format!("-I{}", libpd_wrapper_util_dir.to_str().unwrap()))
         // This is important to generate the right types.
         .clang_arg(format!("-DPD_FLOATSIZE={PD_FLOATSIZE}"))
         // Tell cargo to invalidate the built crate whenever any of the
